require 'json'
require 'uri'
require 'net/http'
# see the URL below for information on how to write OpenStudio measures
# http://nrel.github.io/OpenStudio-user-documentation/measures/measure_writing_guide/
# $servidor = 'http://127.0.0.1:8000'
$servidor = 'http://www.certificomivivienda.es'
# $servidor = nil
# start the measure
class TemperaturaDeAguaDeRed < OpenStudio::Ruleset::WorkspaceUserScript

  # human readable name
  def name
    return " Temperatura de agua de Red"
  end

  # human readable description
  def description
    return "Site:WaterMainsTemperature"
  end

  # human readable description of modeling approach
  def modeler_description
    return "Site:WaterMainsTemperature"
  end

  # define the arguments that the user will input
  def arguments(workspace)
    args = OpenStudio::Ruleset::OSArgumentVector.new

    # the name of the zone to add to the model
    # zone_name = OpenStudio::Ruleset::OSArgument.makeStringArgument("zone_name", true)
    # zone_name.setDisplayName("New zone name")
    # zone_name.setDescription("This name will be used as the name of the new zone.")
    # args << zone_name

    return args
  end 

  # define what happens when the measure is run
  def run(workspace, runner, user_arguments)
    super(workspace, runner, user_arguments)

    # use the built-in error checking 
    if !runner.validateUserArguments(arguments(workspace), user_arguments)
      return false
    end

    # reporting initial condition of model
    runner.registerInitialCondition("Comenzamos...")
    
    model = runner.lastOpenStudioModel
    if model.empty?
      runner.registerError("Cannot find last model.")
      return false
    end
    model = model.get

    zC = zonaClimatica(model)
    esExtraPeninsular = JSON.parse(model.building.get.comment[2..-1])['extraPeninsular']
    
    # Le restamos 3.333333 por que la correlacion se lo suma
    tADR = temperaturaAguaDeRed(zC,esExtraPeninsular) - 3.333333333


    formatoTabla_string = "    
  Site:WaterMainsTemperature,
    CORRELATION,             !- Calculation Method
    ,                       !- Temperature Schedule Name
    #{tADR},                    !- Annual Average Outdoor Air Temperature {C}
    0.0;                   !- Maximum Difference In Monthly Average Outdoor Air Temperatures {deltaC}"      
    idfObject = OpenStudio::IdfObject::load(formatoTabla_string)
    object = idfObject.get
    wsObject = workspace.addObject(object)





    # report final condition of model
    runner.registerFinalCondition("Fin")
    
    return true
 
  end
  
  def zonaClimatica(model)
	climateZones = model.getClimateZones
	clima = climateZones.getClimateZone('CTE',0)
	if clima.value == ''
		return ''
	else
		return clima.value
	end
  end

	def temperaturaAguaDeRed(zonaClimatica,extraPeninsular)
   begin
    uri = URI.parse("#{$servidor}/energyPlus/temperaturaAguaDeRed/")
    response = Net::HTTP.post_form(uri, {"zonaClimatica" => zonaClimatica,
                 "extraPeninsular" => extraPeninsular})

    # Llega un diccionario con la energia semanal y el numero de horas
    temperaturaAguaDeRed = response.body.to_f
    
  rescue
   temperaturaAguaDeRed = 12.8
  end


	  return temperaturaAguaDeRed
	end

end 

# register the measure to be used by the application
TemperaturaDeAguaDeRed.new.registerWithApplication
